from distutils.core import setup

setup(
    name="cri",
    packages=['cri'],
    version='0.1.0',
    description='Python client for kubernetes container runtime interface (CRI)',
    author='Pengfei Ni',
    author_email="feiskyer@gmail.com",
    url="https://github.com/feiskyer/python-cri",
    keywords=['kubernetes', 'kubelet-cri', 'containers'],
)

